[![PyPI](https://img.shields.io/pypi/v/zerotk.easyfs.svg?style=flat-square)]()
[![Travis](https://img.shields.io/travis/zerotk/easyfs.svg?style=flat-square)]()
[![Coveralls](https://img.shields.io/coveralls/zerotk/easyfs.svg?style=flat-square)]()

# zerotk.easyfs

File system utilities for python.

```python
import zerotk.easyfs
```
